{ config, pkgs, lib, modulesPath, ... }:

{
  imports =
    [
      (modulesPath + "/virtualisation/proxmox-lxc.nix")
      ../../base.nix
      ../../common/metrics-exporters.nix

      ./services/nginx.nix
      ./services/postgresql.nix
      ./services/hedgedoc.nix
      ./services/flame.nix
  ];

  # Boot and console is handled by proxmoxLXC.
  boot.loader.systemd-boot.enable = lib.mkForce false; # Enabled in base.nix, forced off here.

  # Override proxmox networking
  proxmoxLXC.manageNetwork = true;
  networking = {
    hostName = "sarek";
    defaultGateway = "192.168.10.1";
    interfaces."eth0".ipv4 = {
      addresses = [
        { address = "192.168.10.181"; prefixLength = 24; }
      ];
    };
    hostId = "15dd36bc";
  };

  sops.defaultSopsFile = ../../secrets/sarek/sarek.yaml;

  virtualisation.podman = {
    enable = true;
    dockerCompat = true; # Make `docker` shell alias
    defaultNetwork.settings.dns_enabled = true;
  };

  virtualisation.oci-containers.backend = "podman";

  system.stateVersion = "23.05";
}

